pub enum SyncOrStrippedState<C>where
C: StaticStateEventContent + RedactContent,
<C as RedactContent>::Redacted: RedactedStateEventContent + Debug + Clone,{
Sync(SyncStateEvent<C>),
Stripped(StrippedStateEvent<<C as StaticStateEventContent>::PossiblyRedacted>),
}Expand description
Wrapper around both versions of a state event.
Variants
Sync(SyncStateEvent<C>)
An event from a room in joined or left state.
Stripped(StrippedStateEvent<<C as StaticStateEventContent>::PossiblyRedacted>)
An event from a room in invited state.
Implementations
Sourceimpl<C> SyncOrStrippedState<C>where
C: RedactContent + StaticStateEventContent,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + Debug + Clone,
<C as StaticStateEventContent>::PossiblyRedacted: PossiblyRedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey>,
impl<C> SyncOrStrippedState<C>where
C: RedactContent + StaticStateEventContent,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + Debug + Clone,
<C as StaticStateEventContent>::PossiblyRedacted: PossiblyRedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey>,
Sourcepub fn as_sync(&self) -> Option<&SyncStateEvent<C>>
pub fn as_sync(&self) -> Option<&SyncStateEvent<C>>
If this is a SyncStateEvent, return a reference to the inner event.
Sourcepub fn as_stripped(
&self,
) -> Option<&StrippedStateEvent<<C as StaticStateEventContent>::PossiblyRedacted>>
pub fn as_stripped( &self, ) -> Option<&StrippedStateEvent<<C as StaticStateEventContent>::PossiblyRedacted>>
If this is a StrippedStateEvent, return a reference to the inner
event.
Sourcepub fn origin_server_ts(&self) -> Option<MilliSecondsSinceUnixEpoch>
pub fn origin_server_ts(&self) -> Option<MilliSecondsSinceUnixEpoch>
The server timestamp of this event.
Sourcepub fn state_key(&self) -> &<C as StateEventContent>::StateKey
pub fn state_key(&self) -> &<C as StateEventContent>::StateKey
The state key associated to this state event.
Sourceimpl<C> SyncOrStrippedState<C>where
C: RedactContent + PossiblyRedactedStateEventContent + StaticStateEventContent<PossiblyRedacted = C>,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + Debug + Clone,
impl<C> SyncOrStrippedState<C>where
C: RedactContent + PossiblyRedactedStateEventContent + StaticStateEventContent<PossiblyRedacted = C>,
<C as RedactContent>::Redacted: RedactedStateEventContent<StateKey = <C as StateEventContent>::StateKey> + Debug + Clone,
Sourcepub fn original_content(&self) -> Option<&C>
pub fn original_content(&self) -> Option<&C>
The inner content of the wrapped event.
Sourceimpl SyncOrStrippedState<RoomMemberEventContent>
impl SyncOrStrippedState<RoomMemberEventContent>
Sourcepub fn membership(&self) -> &MembershipState
pub fn membership(&self) -> &MembershipState
The membership state of the user.
Sourcepub fn displayname_value(&self) -> Option<&str>
pub fn displayname_value(&self) -> Option<&str>
The value of the displayname field in this member event.
MemberEvent::display_name() should be preferred to get the name to
display for this member event.
Sourcepub fn display_name(&self) -> DisplayName
pub fn display_name(&self) -> DisplayName
The name that should be displayed for this member event.
It there is no displayname in the event’s content, the localpart or
the user ID is returned.
Sourcepub fn avatar_url(&self) -> Option<&MxcUri>
pub fn avatar_url(&self) -> Option<&MxcUri>
The URL of the avatar in this member event.
MemberEvent::display_name() should be preferred to get the name to
display for this member event.
Sourceimpl SyncOrStrippedState<RoomPowerLevelsEventContent>
impl SyncOrStrippedState<RoomPowerLevelsEventContent>
Sourcepub fn power_levels(
&self,
rules: &AuthorizationRules,
creators: Vec<OwnedUserId>,
) -> RoomPowerLevels
pub fn power_levels( &self, rules: &AuthorizationRules, creators: Vec<OwnedUserId>, ) -> RoomPowerLevels
The power levels of the event.